use std::{fs, path};

pub fn join(path: &String) -> String {
    let p = path::PathBuf::from(path);
    p.to_string_lossy().to_string()
}

pub fn file_exists(filename: &String) -> bool {
    let meta = fs::metadata(filename);
    match meta {
        Ok(meta) => {
            meta.is_file() || meta.is_symlink()
        }
        Err(_) => false
    }
}

pub fn dir_exists(dirname: &String) -> bool {
    let meta = fs::metadata(dirname);
    match meta {
        Ok(meta) => {
            meta.is_dir()
        }
        Err(_) => false
    }
}

pub fn read_file(filename: &String) -> String {
    let content = fs::read_to_string(filename);
    match content {
        Ok(content) => {
            content
        }
        Err(_) => String::new()
    }
}

pub fn read_dir(dirname: &String, include_dirs: bool) -> Vec<String> {
    let mut result: Vec<String> = Vec::new();
    let dir = fs::read_dir(dirname);
    match dir {
        Ok(dir) => {
            for entry in dir {
                if let Ok(entry) = entry {
                    let path = entry.path();
                    if path.is_dir() && include_dirs {
                        result.push(format!("{}/", path.to_string_lossy().to_string()));
                    } else if path.is_file() || path.is_symlink() {
                        result.push(path.to_string_lossy().to_string());
                    }
                }
            }
            result
        }
        Err(_) => Vec::new()
    }
}

pub fn write_file(filename: &String, contents: &String) -> bool {
    let ok = fs::write(filename, contents);
    match ok {
        Ok(_) => true,
        Err(_) => false
    }
}

pub fn mkdir(dirname: &String) -> bool {
    let ok = fs::create_dir_all(dirname);
    match ok {
        Ok(_) => true,
        Err(_) => false
    }
}
